<!DOCTYPE html>
<html lang="en">
<head>
</head>
<body>
  <p>Hello,</p>
  <p>Follow this link to reset your {{ app_name }} password for your {{ email }} account.</p>
  <p><a href='{{ link }}'>{{ link }}</a></p>
  <p>If you didn’t ask to reset your password, you can contact us.</p>
  <p>Thanks,</p>
  <p>Your {{ app_name }} team</p>
</body>
</html>